;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;		Csound instruments for
; 
;		Canone Monodico a 4
;		
;		(Interlock #4)
;
;		by Maximilian Marcoll
;		2019
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


<CsoundSynthesizer>
<CsOptions>



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; M I D I 
;
	-M0
;
; the following setting will produce an error but will show
; you a list of available midi devices and their device numbers:
;
	-M100
;
; simply comment it out (put a semicolon in front of it) and change the number in the
; setting above to the desired midi input device 
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; A U D I O

	-odac0

; the following setting will produce an error but will show
; you a list of available audio devices and their device numbers:
;
	-odac100
;
; simply comment it out (put a semicolon in front of it) and change the number in the
; setting above to the desired audio output device 
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


	-m99

</CsOptions>
<CsInstruments>

	nchnls = 1
	ksmps = 1
	0dbfs = 1


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	; Use this to record the live generated signal into "LiveRec.aif" :
	; #define WriteToDisk # #

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


	turnon "saw"

	giSubDBTable 	ftgen 	0, 0, 32768, -6, 0, 81, 0, 75, -90, 32587, -90
		
	giInterRamp		=		0.01
	giOnOff 		= 		0
	giStartRamp		= 		0.3
	giDefaultCPS	= 		339.286
	giDBRange		=		30

	giRangeOctA		=		2.914
	giRangeOctB		=		1.362
	giRangeOctC		=		.711
	giRangeOctD		=		2.263
	
	giOctRange 		= 		giRangeOctA + giRangeOctB + giRangeOctC + giRangeOctD
	giMinFreq 		= 		giDefaultCPS * pow(2, (giOctRange / 2)*-1);
	
	giMidiCenterPitch = 	72

	giStepsizeA		= 		pow(2, (1/12) * (giRangeOctA/2))
	giStepsizeB		= 		pow(2, (1/12) * (giRangeOctB/2))
	giStepsizeC		= 		pow(2, (1/12) * (giRangeOctC/2))
	giStepsizeD		= 		pow(2, (1/12) * (giRangeOctD/2))

	gkFreq			init 	1
	gkFac1	 		init 	1
	gkFac2	 		init 	1
	gkFac3	 		init 	1
	gkFac4	 		init 	1	



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	#define Detune(inum'stepSize'fac) #

		instr $inum 
			
			gkTrig = 1

			mididefault 	giStartRamp, p3 
			midinoteonkey 	p4, p5
			
			iPitch 	limit 	p4, 60, 84
			
			ifac 	pow 	$stepSize, iPitch - giMidiCenterPitch
			
			$fac  	linseg 	i($fac), giInterRamp, ifac, p3-giInterRamp, ifac

		endin
	#

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	$Detune(1'giStepsizeA'gkFac1)
	$Detune(2'giStepsizeB'gkFac2) 
	$Detune(3'giStepsizeC'gkFac3) 
	$Detune(4'giStepsizeD'gkFac4) 

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	instr saw


		
		k1 		active 1
		k2 		active 2
		k3 		active 3
		k4 		active 4
		ksum 	= 		k1 + k2 + k3 + k4
		kperf 	= 		ksum > 0 ? 1 : 0

		ktrig 	trigger ksum, .5, 0
				schedkwhen ktrig, 0, 1, "ramp", 0, giStartRamp



		kFreq 	= 		gkFreq * gkFac1 * gkFac2 * gkFac3 * gkFac4
		koct 	log2 	kFreq/giMinFreq;
		kdBFac 	= 		koct/giOctRange
		kdamp 	= 		kdBFac * giDBRange;
		kdB 	= 		0 - kdamp;

		kLinVol = 		pow(10, kdB/20) * kperf

		kLinVol limit 	kLinVol, 0, 1
				
		aSaw 	vco2 	1, kFreq, 0, 0, 0, .5

		kSubdB	tablei  kFreq, giSubDBTable
		kSubAmp db 		kSubdB

		aSub 	poscil 	kSubAmp * .75, kFreq * .5

		aOut 	= 		(aSaw * .75 + aSub)*kLinVol

				out aOut

		#ifdef WriteToDisk
			fout "LiveRec.aif", 24, aOut
		#end

	endin

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	instr ramp

		gkFreq expon 	1, p3, giDefaultCPS		
		giOnOff = 1

	endin

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


</CsInstruments>
<CsScore>
</CsScore>
</CsoundSynthesizer>